/* 
 * tclLoadNone.c --
 *
 *	This procedure provides a version of the dlopen() for use
 *	in systems that don't support dynamic loading; It will
 *	work if the library libz.a is statically linked into
 *	a modified tclsh or wish.
 *
 * Copyright (c) 1995-1996 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS: @(#) tclLoadNone.c 1.5 96/02/15 11:43:01
 */

#include "tcl.h"
#include "compat/dlfcn.h"

extern int inflate();
extern int inflateInit2_();
extern int inflateEnd();

static struct {
  char * name;
  int (*value)();
}dictionary [] = {
  {"inflateInit2_", inflateInit2_},
  {"inflate", inflate},
  {"inflateEnd", inflateEnd},
  {0, 0}
};

/*
 *----------------------------------------------------------------------
 *
 * dlopen  --
 * dlsym   --
 * dlerror --
 * dlclose --
 *
 *	Minimal replacement functions, in case our system doesn't support
 *	dynamic loading.
 *
 * Results:
 *	If the library is libz, dlsym() correctly returns
 *      the requested function adresses, provided that
 *      zlib is statically linked together with this file.
 *      dlopen, dlerror and dlclose are dummy functions.
 *
 * Side effects:
 *	None
 *
 *----------------------------------------------------------------------
 */
VOID *dlopen(path, mode)
    CONST char *path;
    int mode;
{
    return (VOID *) 1;
}

VOID *dlsym(handle, symbol)
    VOID *handle;
    CONST char *symbol;
{
    int i;
    for (i = 0; dictionary[i].name != 0; ++i) {
      if (!strcmp(symbol, dictionary[i].name)) {
	return (VOID *) dictionary [i].value;
      }
    }
    return (VOID *) NULL;
}

char *dlerror()
{
    return "dynamic loading is not currently available on this system";
}

int dlclose(handle)
    VOID *handle;
{
    return 0;
}
